==> 0.0.20.tar.gz: lib/widgets/src/search_bar.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class SearchBar extends StatefulWidget {
  const SearchBar({
    Key? key,
    required this.hint,
    this.initText,
    this.onChange,
    this.onSearch,
    this.onTap,
    this.height,
    this.fillColor = const Color(0xffF2F3F5),
    this.enableBorder,
    this.focusBorder,
  }) : super(key: key);

  final String hint;
  final String? initText;
  final Function(String)? onChange;
  final Function(String)? onSearch;
  final double? height;
  final Function()? onTap;
  final Color fillColor;
  final OutlineInputBorder? enableBorder;
  final OutlineInputBorder? focusBorder;

  @override
  State<SearchBar> createState() => _SearchBarState();
}

class _SearchBarState extends State<SearchBar> {
  final TextEditingController controller = TextEditingController();
  @override
  void initState() {
    super.initState();
    controller.text = widget.initText ?? "";
    controller.addListener(() {
      setState(() {});
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: widget.onTap,
      child: ConstrainedBox(
        constraints: BoxConstraints(
          maxHeight: widget.height ?? 36.h,
        ),
        child: TextField(
          enabled: widget.onTap == null,
          controller: controller,
          onSubmitted: (text) {
            widget.onSearch?.call(text);
          },
          onChanged: (text) {
            widget.onChange?.call(text);
          },
          textInputAction: TextInputAction.search,
          decoration: InputDecoration(
            filled: true,
            fillColor: widget.fillColor,
            contentPadding: EdgeInsets.zero,
            prefixIcon: Icon(
              const IconData(
                0xe688,
                fontFamily: "iconFont",
                matchTextDirection: true,
              ),
              size: 16.r,
              color: const Color(0xff969799),
            ),
            prefixIconConstraints: BoxConstraints.tightFor(
              width: 36.w,
              height: 16.h,
            ),
            suffixIcon: controller.text.isNotEmpty
                ? IconButton(
                    onPressed: () {
                      // 保证在组件build的第一帧时才去触发取消清空内容 fmq
                      WidgetsBinding.instance?.addPostFrameCallback((_) => controller.clear());
                      if(mounted) {
                        setState(() {});
                        if(widget.onChange != null) {
                          widget.onChange?.call("");
                        } else {
                          widget.onSearch?.call("");
                        }
                      }
                    },
                    icon: Icon(
                      const IconData(
                        0xe6d7,
                        fontFamily: "iconFont",
                        matchTextDirection: true,
                      ),
                      size: 16.r,
                      color: const Color(0xff969799),
                    ),
                  )
                : null,
            hintText: widget.hint,
            border: widget.enableBorder ??
                OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(8.r)),
                  borderSide: BorderSide.none,
                ),
            enabledBorder: widget.enableBorder ??
                OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(8.r)),
                  borderSide: BorderSide.none,
                ),
            focusedBorder: widget.focusBorder ??
                OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(8.r)),
                  borderSide: BorderSide.none,
                ),
          ),
          style: TextStyle(
            color: const Color(0xff323233),
            fontSize: 14.sp,
          ),
        ),
      ),
    );
  }

  @override
  void dispose() {
    super.dispose();
  }
}

==> 0.0.71.tar.gz: lib/widgets/src/search_bar.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class TSearchBar extends StatefulWidget {
  const TSearchBar({
    Key? key,
    required this.hint,
    this.initText,
    this.onChange,
    this.onSearch,
    this.onTap,
    this.height,
    this.fillColor = const Color(0xffF2F3F5),
    this.enableBorder,
    this.focusBorder,
    this.searchIcon = const Icon(
                              IconData(
                                0xe688,
                                fontFamily: "iconFont",
                                matchTextDirection: true,
                              ),
                              size: 16,
                              color: Color(0xff969799),
                            ),
    this.clearIcon = const Icon(
                            IconData(
                              0xe6d7,
                              fontFamily: "iconFont",
                              matchTextDirection: true,
                            ),
                            size: 16,
                            color: Color(0xff969799),
                          )
  }) : super(key: key);

  final String hint;
  final String? initText;
  final Function(String)? onChange;
  final Function(String)? onSearch;
  final double? height;
  final Function()? onTap;
  final Color fillColor;
  final OutlineInputBorder? enableBorder;
  final OutlineInputBorder? focusBorder;
  final Icon? searchIcon;
  final Icon clearIcon;

  @override
  State<TSearchBar> createState() => _TSearchBarState();
}

class _TSearchBarState extends State<TSearchBar> {
  final TextEditingController controller = TextEditingController();
  @override
  void initState() {
    super.initState();
    controller.text = widget.initText ?? "";
    controller.addListener(() {
      setState(() {});
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: widget.onTap,
      child: ConstrainedBox(
        constraints: BoxConstraints(
          maxHeight: widget.height ?? 36.h,
        ),
        child: TextField(
          enabled: widget.onTap == null,
          controller: controller,
          onSubmitted: (text) {
            widget.onSearch?.call(text);
          },
          onChanged: (text) {
            widget.onChange?.call(text);
          },
          textInputAction: TextInputAction.search,
          decoration: InputDecoration(
            filled: true,
            fillColor: widget.fillColor,
            contentPadding: EdgeInsets.zero,
            prefixIcon: widget.searchIcon,
            prefixIconConstraints: BoxConstraints.tightFor(
              width: 36.w,
              height: 16.h,
            ),
            suffixIcon: controller.text.isNotEmpty
                ? IconButton(
                    onPressed: () {
                      // 保证在组件build的第一帧时才去触发取消清空内容 fmq
                      WidgetsBinding.instance.addPostFrameCallback((_) => controller.clear());
                      if(mounted) {
                        setState(() {});
                        if(widget.onChange != null) {
                          widget.onChange?.call("");
                        } else {
                          widget.onSearch?.call("");
                        }
                      }
                    },
                    icon: widget.clearIcon,
                  )
                : null,
            hintText: widget.hint,
            border: widget.enableBorder ??
                OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(8.r)),
                  borderSide: BorderSide.none,
                ),
            enabledBorder: widget.enableBorder ??
                OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(8.r)),
                  borderSide: BorderSide.none,
                ),
            focusedBorder: widget.focusBorder ??
                OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(8.r)),
                  borderSide: BorderSide.none,
                ),
          ),
          style: TextStyle(
            color: const Color(0xff323233),
            fontSize: 14.sp,
          ),
        ),
      ),
    );
  }

  @override
  void dispose() {
    super.dispose();
  }
}
